/****************************************************************************
** Meta object code from reading C++ file 'searchpatternedit.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../mailcommon-26.04.3/src/search/searchpatternedit.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'searchpatternedit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MailCommon17SearchPatternEditE_t {};
} // unnamed namespace

template <> constexpr inline auto MailCommon::SearchPatternEdit::qt_create_metaobjectdata<qt_meta_tag_ZN10MailCommon17SearchPatternEditE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MailCommon::SearchPatternEdit",
        "maybeNameChanged",
        "",
        "patternChanged",
        "returnPressed",
        "reset"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'maybeNameChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'patternChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'returnPressed'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SearchPatternEdit, qt_meta_tag_ZN10MailCommon17SearchPatternEditE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MailCommon::SearchPatternEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MailCommon17SearchPatternEditE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MailCommon17SearchPatternEditE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MailCommon17SearchPatternEditE_t>.metaTypes,
    nullptr
} };

void MailCommon::SearchPatternEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SearchPatternEdit *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->maybeNameChanged(); break;
        case 1: _t->patternChanged(); break;
        case 2: _t->returnPressed(); break;
        case 3: _t->reset(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SearchPatternEdit::*)()>(_a, &SearchPatternEdit::maybeNameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SearchPatternEdit::*)()>(_a, &SearchPatternEdit::patternChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SearchPatternEdit::*)()>(_a, &SearchPatternEdit::returnPressed, 2))
            return;
    }
}

const QMetaObject *MailCommon::SearchPatternEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MailCommon::SearchPatternEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MailCommon17SearchPatternEditE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int MailCommon::SearchPatternEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void MailCommon::SearchPatternEdit::maybeNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MailCommon::SearchPatternEdit::patternChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MailCommon::SearchPatternEdit::returnPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN10MailCommon16SearchRuleWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto MailCommon::SearchRuleWidget::qt_create_metaobjectdata<qt_meta_tag_ZN10MailCommon16SearchRuleWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MailCommon::SearchRuleWidget",
        "fieldChanged",
        "",
        "contentsChanged",
        "returnPressed",
        "addWidget",
        "QWidget*",
        "removeWidget",
        "slotFunctionChanged",
        "slotValueChanged",
        "slotReturnPressed",
        "slotRuleFieldChanged",
        "slotAddWidget",
        "slotRemoveWidget"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fieldChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'contentsChanged'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'returnPressed'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addWidget'
        QtMocHelpers::SignalData<void(QWidget *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'removeWidget'
        QtMocHelpers::SignalData<void(QWidget *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'slotFunctionChanged'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotValueChanged'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotReturnPressed'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRuleFieldChanged'
        QtMocHelpers::SlotData<void(const QString &)>(11, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'slotAddWidget'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotRemoveWidget'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SearchRuleWidget, qt_meta_tag_ZN10MailCommon16SearchRuleWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MailCommon::SearchRuleWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MailCommon16SearchRuleWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MailCommon16SearchRuleWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MailCommon16SearchRuleWidgetE_t>.metaTypes,
    nullptr
} };

void MailCommon::SearchRuleWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SearchRuleWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fieldChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->contentsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->returnPressed(); break;
        case 3: _t->addWidget((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 4: _t->removeWidget((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 5: _t->slotFunctionChanged(); break;
        case 6: _t->slotValueChanged(); break;
        case 7: _t->slotReturnPressed(); break;
        case 8: _t->slotRuleFieldChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->slotAddWidget(); break;
        case 10: _t->slotRemoveWidget(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SearchRuleWidget::*)(const QString & )>(_a, &SearchRuleWidget::fieldChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SearchRuleWidget::*)(const QString & )>(_a, &SearchRuleWidget::contentsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SearchRuleWidget::*)()>(_a, &SearchRuleWidget::returnPressed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SearchRuleWidget::*)(QWidget * )>(_a, &SearchRuleWidget::addWidget, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SearchRuleWidget::*)(QWidget * )>(_a, &SearchRuleWidget::removeWidget, 4))
            return;
    }
}

const QMetaObject *MailCommon::SearchRuleWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MailCommon::SearchRuleWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MailCommon16SearchRuleWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int MailCommon::SearchRuleWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void MailCommon::SearchRuleWidget::fieldChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void MailCommon::SearchRuleWidget::contentsChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void MailCommon::SearchRuleWidget::returnPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MailCommon::SearchRuleWidget::addWidget(QWidget * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void MailCommon::SearchRuleWidget::removeWidget(QWidget * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN10MailCommon22SearchRuleWidgetListerE_t {};
} // unnamed namespace

template <> constexpr inline auto MailCommon::SearchRuleWidgetLister::qt_create_metaobjectdata<qt_meta_tag_ZN10MailCommon22SearchRuleWidgetListerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MailCommon::SearchRuleWidgetLister",
        "reset",
        "",
        "slotAddWidget",
        "QWidget*",
        "slotRemoveWidget"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddWidget'
        QtMocHelpers::SlotData<void(QWidget *)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Slot 'slotRemoveWidget'
        QtMocHelpers::SlotData<void(QWidget *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SearchRuleWidgetLister, qt_meta_tag_ZN10MailCommon22SearchRuleWidgetListerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MailCommon::SearchRuleWidgetLister::staticMetaObject = { {
    QMetaObject::SuperData::link<KPIM::KWidgetLister::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MailCommon22SearchRuleWidgetListerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MailCommon22SearchRuleWidgetListerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MailCommon22SearchRuleWidgetListerE_t>.metaTypes,
    nullptr
} };

void MailCommon::SearchRuleWidgetLister::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SearchRuleWidgetLister *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->reset(); break;
        case 1: _t->slotAddWidget((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        case 2: _t->slotRemoveWidget((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *MailCommon::SearchRuleWidgetLister::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MailCommon::SearchRuleWidgetLister::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MailCommon22SearchRuleWidgetListerE_t>.strings))
        return static_cast<void*>(this);
    return KPIM::KWidgetLister::qt_metacast(_clname);
}

int MailCommon::SearchRuleWidgetLister::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPIM::KWidgetLister::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}
QT_WARNING_POP
