/********************************************************************************
** Form generated from reading UI file 'selectthunderbirdfilterfileswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SELECTTHUNDERBIRDFILTERFILESWIDGET_H
#define UI_SELECTTHUNDERBIRDFILTERFILESWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_SelectThunderbirdFilterFilesWidget
{
public:
    QGridLayout *gridLayout;
    QRadioButton *selectFile;
    KUrlRequester *fileUrl;
    QRadioButton *selectFromConfig;
    KComboBox *profiles;
    QListWidget *listFiles;
    QButtonGroup *buttonGroup;

    void setupUi(QWidget *SelectThunderbirdFilterFilesWidget)
    {
        if (SelectThunderbirdFilterFilesWidget->objectName().isEmpty())
            SelectThunderbirdFilterFilesWidget->setObjectName("SelectThunderbirdFilterFilesWidget");
        SelectThunderbirdFilterFilesWidget->resize(400, 300);
        gridLayout = new QGridLayout(SelectThunderbirdFilterFilesWidget);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        selectFile = new QRadioButton(SelectThunderbirdFilterFilesWidget);
        buttonGroup = new QButtonGroup(SelectThunderbirdFilterFilesWidget);
        buttonGroup->setObjectName("buttonGroup");
        buttonGroup->addButton(selectFile);
        selectFile->setObjectName("selectFile");
        selectFile->setChecked(true);

        gridLayout->addWidget(selectFile, 0, 0, 1, 1);

        fileUrl = new KUrlRequester(SelectThunderbirdFilterFilesWidget);
        fileUrl->setObjectName("fileUrl");

        gridLayout->addWidget(fileUrl, 0, 1, 1, 1);

        selectFromConfig = new QRadioButton(SelectThunderbirdFilterFilesWidget);
        buttonGroup->addButton(selectFromConfig);
        selectFromConfig->setObjectName("selectFromConfig");

        gridLayout->addWidget(selectFromConfig, 1, 0, 1, 1);

        profiles = new KComboBox(SelectThunderbirdFilterFilesWidget);
        profiles->setObjectName("profiles");

        gridLayout->addWidget(profiles, 1, 1, 1, 1);

        listFiles = new QListWidget(SelectThunderbirdFilterFilesWidget);
        listFiles->setObjectName("listFiles");

        gridLayout->addWidget(listFiles, 2, 0, 1, 2);


        retranslateUi(SelectThunderbirdFilterFilesWidget);

        QMetaObject::connectSlotsByName(SelectThunderbirdFilterFilesWidget);
    } // setupUi

    void retranslateUi(QWidget *SelectThunderbirdFilterFilesWidget)
    {
        selectFile->setText(tr2i18n("Select File:", nullptr));
        selectFromConfig->setText(tr2i18n("Select file from config:", nullptr));
        (void)SelectThunderbirdFilterFilesWidget;
    } // retranslateUi

};

namespace Ui {
    class SelectThunderbirdFilterFilesWidget: public Ui_SelectThunderbirdFilterFilesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SELECTTHUNDERBIRDFILTERFILESWIDGET_H

