/****************************************************************************
** Meta object code from reading C++ file 'kmfilterdialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../mailcommon-26.04.3/src/filter/kmfilterdialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmfilterdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MailCommon14KMFilterDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto MailCommon::KMFilterDialog::qt_create_metaobjectdata<qt_meta_tag_ZN10MailCommon14KMFilterDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MailCommon::KMFilterDialog",
        "slotFilterSelected",
        "",
        "MailCommon::MailFilter*",
        "aFilter",
        "accept",
        "slotApplicabilityChanged",
        "slotApplicableAccountsChanged",
        "slotStopProcessingButtonToggled",
        "aChecked",
        "slotShortcutChanged",
        "QKeySequence",
        "newSeq",
        "slotConfigureToolbarButtonToggled",
        "slotFilterActionIconChanged",
        "icon",
        "slotReset",
        "slotUpdateFilter",
        "slotSaveSize",
        "slotFinished",
        "slotUpdateAccountList",
        "slotImportFilter",
        "QAction*",
        "slotExportFilters",
        "slotDisableAccept",
        "slotDialogUpdated",
        "slotApply",
        "slotRunFilters",
        "slotFetchItemsForFolderDone",
        "KJob*",
        "job",
        "slotFolderChanged",
        "Akonadi::Collection"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotFilterSelected'
        QtMocHelpers::SlotData<void(MailCommon::MailFilter *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'accept'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotApplicabilityChanged'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotApplicableAccountsChanged'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotStopProcessingButtonToggled'
        QtMocHelpers::SlotData<void(bool)>(8, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'slotShortcutChanged'
        QtMocHelpers::SlotData<void(const QKeySequence &)>(10, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'slotConfigureToolbarButtonToggled'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'slotFilterActionIconChanged'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'slotReset'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotUpdateFilter'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotSaveSize'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotFinished'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotUpdateAccountList'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotImportFilter'
        QtMocHelpers::SlotData<void(QAction *)>(21, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 22, 2 },
        }}),
        // Slot 'slotExportFilters'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotDisableAccept'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotDialogUpdated'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotApply'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotRunFilters'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotFetchItemsForFolderDone'
        QtMocHelpers::SlotData<void(KJob *)>(28, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'slotFolderChanged'
        QtMocHelpers::SlotData<void(const Akonadi::Collection &)>(31, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 32, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KMFilterDialog, qt_meta_tag_ZN10MailCommon14KMFilterDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MailCommon::KMFilterDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MailCommon14KMFilterDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MailCommon14KMFilterDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MailCommon14KMFilterDialogE_t>.metaTypes,
    nullptr
} };

void MailCommon::KMFilterDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KMFilterDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotFilterSelected((*reinterpret_cast<std::add_pointer_t<MailCommon::MailFilter*>>(_a[1]))); break;
        case 1: _t->accept(); break;
        case 2: _t->slotApplicabilityChanged(); break;
        case 3: _t->slotApplicableAccountsChanged(); break;
        case 4: _t->slotStopProcessingButtonToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->slotShortcutChanged((*reinterpret_cast<std::add_pointer_t<QKeySequence>>(_a[1]))); break;
        case 6: _t->slotConfigureToolbarButtonToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->slotFilterActionIconChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->slotReset(); break;
        case 9: _t->slotUpdateFilter(); break;
        case 10: _t->slotSaveSize(); break;
        case 11: _t->slotFinished(); break;
        case 12: _t->slotUpdateAccountList(); break;
        case 13: _t->slotImportFilter((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 14: _t->slotExportFilters(); break;
        case 15: _t->slotDisableAccept(); break;
        case 16: _t->slotDialogUpdated(); break;
        case 17: _t->slotApply(); break;
        case 18: _t->slotRunFilters(); break;
        case 19: _t->slotFetchItemsForFolderDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 20: _t->slotFolderChanged((*reinterpret_cast<std::add_pointer_t<Akonadi::Collection>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *MailCommon::KMFilterDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MailCommon::KMFilterDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MailCommon14KMFilterDialogE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int MailCommon::KMFilterDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}
QT_WARNING_POP
