/********************************************************************************
** Form generated from reading UI file 'snippetwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SNIPPETWIDGET_H
#define UI_SNIPPETWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "Akonadi/EmailAddressRequester"
#include "kkeysequencewidget.h"
#include "klineedit.h"
#include "snippets/snippetattachmentwidget.h"
#include "textcustomeditor/plaintexteditorwidget.h"

QT_BEGIN_NAMESPACE

class Ui_SnippetWidget
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *nameLabel;
    KLineEdit *nameEdit;
    QLabel *textLabelGroup;
    QComboBox *groupBox;
    QLabel *label_2;
    KLineEdit *subject;
    QLabel *label_3;
    Akonadi::EmailAddressRequester *to;
    QLabel *label_4;
    Akonadi::EmailAddressRequester *cc;
    QLabel *label_5;
    Akonadi::EmailAddressRequester *bcc;
    QLabel *textLabel;
    TextCustomEditor::PlainTextEditorWidget *snippetText;
    QHBoxLayout *hboxLayout;
    QPushButton *pushButtonVariables;
    QSpacerItem *horizontalSpacer;
    QLabel *label_6;
    MailCommon::SnippetAttachmentWidget *attachment;
    QLabel *label;
    KLineEdit *keyword;
    QLabel *keyWidgetLabel;
    KKeySequenceWidget *keyWidget;

    void setupUi(QWidget *SnippetWidget)
    {
        if (SnippetWidget->objectName().isEmpty())
            SnippetWidget->setObjectName("SnippetWidget");
        SnippetWidget->resize(549, 638);
        verticalLayout = new QVBoxLayout(SnippetWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        nameLabel = new QLabel(SnippetWidget);
        nameLabel->setObjectName("nameLabel");
        nameLabel->setWordWrap(false);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, nameLabel);

        nameEdit = new KLineEdit(SnippetWidget);
        nameEdit->setObjectName("nameEdit");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, nameEdit);

        textLabelGroup = new QLabel(SnippetWidget);
        textLabelGroup->setObjectName("textLabelGroup");
        textLabelGroup->setWordWrap(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, textLabelGroup);

        groupBox = new QComboBox(SnippetWidget);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, groupBox);

        label_2 = new QLabel(SnippetWidget);
        label_2->setObjectName("label_2");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_2);

        subject = new KLineEdit(SnippetWidget);
        subject->setObjectName("subject");
        subject->setClearButtonEnabled(true);
        subject->setProperty("trapEnterKeyEvent", QVariant(true));

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, subject);

        label_3 = new QLabel(SnippetWidget);
        label_3->setObjectName("label_3");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_3);

        to = new Akonadi::EmailAddressRequester(SnippetWidget);
        to->setObjectName("to");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, to);

        label_4 = new QLabel(SnippetWidget);
        label_4->setObjectName("label_4");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_4);

        cc = new Akonadi::EmailAddressRequester(SnippetWidget);
        cc->setObjectName("cc");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, cc);

        label_5 = new QLabel(SnippetWidget);
        label_5->setObjectName("label_5");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_5);

        bcc = new Akonadi::EmailAddressRequester(SnippetWidget);
        bcc->setObjectName("bcc");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, bcc);

        textLabel = new QLabel(SnippetWidget);
        textLabel->setObjectName("textLabel");
        textLabel->setAlignment(Qt::AlignTop);
        textLabel->setWordWrap(false);

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, textLabel);

        snippetText = new TextCustomEditor::PlainTextEditorWidget(SnippetWidget);
        snippetText->setObjectName("snippetText");
        QFont font;
        font.setFamilies({QString::fromUtf8("Courier")});
        font.setPointSize(11);
        snippetText->setFont(font);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, snippetText);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        pushButtonVariables = new QPushButton(SnippetWidget);
        pushButtonVariables->setObjectName("pushButtonVariables");

        hboxLayout->addWidget(pushButtonVariables);

        horizontalSpacer = new QSpacerItem(347, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(horizontalSpacer);


        formLayout->setLayout(7, QFormLayout::ItemRole::FieldRole, hboxLayout);

        label_6 = new QLabel(SnippetWidget);
        label_6->setObjectName("label_6");

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, label_6);

        attachment = new MailCommon::SnippetAttachmentWidget(SnippetWidget);
        attachment->setObjectName("attachment");

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, attachment);

        label = new QLabel(SnippetWidget);
        label->setObjectName("label");

        formLayout->setWidget(9, QFormLayout::ItemRole::LabelRole, label);

        keyword = new KLineEdit(SnippetWidget);
        keyword->setObjectName("keyword");
        keyword->setProperty("trapEnterKeyEvent", QVariant(true));
        keyword->setProperty("showClearButton", QVariant(true));

        formLayout->setWidget(9, QFormLayout::ItemRole::FieldRole, keyword);

        keyWidgetLabel = new QLabel(SnippetWidget);
        keyWidgetLabel->setObjectName("keyWidgetLabel");
        keyWidgetLabel->setWordWrap(false);

        formLayout->setWidget(10, QFormLayout::ItemRole::LabelRole, keyWidgetLabel);

        keyWidget = new KKeySequenceWidget(SnippetWidget);
        keyWidget->setObjectName("keyWidget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(keyWidget->sizePolicy().hasHeightForWidth());
        keyWidget->setSizePolicy(sizePolicy1);

        formLayout->setWidget(10, QFormLayout::ItemRole::FieldRole, keyWidget);


        verticalLayout->addLayout(formLayout);

#if QT_CONFIG(shortcut)
        nameLabel->setBuddy(nameEdit);
        textLabel->setBuddy(snippetText);
        keyWidgetLabel->setBuddy(keyWidget);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(nameEdit, groupBox);
        QWidget::setTabOrder(groupBox, subject);
        QWidget::setTabOrder(subject, to);
        QWidget::setTabOrder(to, cc);
        QWidget::setTabOrder(cc, bcc);
        QWidget::setTabOrder(bcc, keyword);

        retranslateUi(SnippetWidget);

        QMetaObject::connectSlotsByName(SnippetWidget);
    } // setupUi

    void retranslateUi(QWidget *SnippetWidget)
    {
        nameLabel->setText(tr2i18n("&Name:", nullptr));
        textLabelGroup->setText(tr2i18n("Group:", "Group to which the snippet belongs."));
        label_2->setText(tr2i18n("Subject:", nullptr));
        label_3->setText(tr2i18n("To:", nullptr));
        label_4->setText(tr2i18n("Cc:", nullptr));
        label_5->setText(tr2i18n("Bcc:", nullptr));
        textLabel->setText(tr2i18n("&Snippet:", nullptr));
        pushButtonVariables->setText(tr2i18n("Variables", nullptr));
        label_6->setText(tr2i18n("Attachments:", nullptr));
        label->setText(tr2i18n("Keyword:", nullptr));
        keyWidgetLabel->setText(tr2i18n("Sho&rtcut:", nullptr));
        (void)SnippetWidget;
    } // retranslateUi

};

namespace Ui {
    class SnippetWidget: public Ui_SnippetWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SNIPPETWIDGET_H

