/****************************************************************************
** Meta object code from reading C++ file 'kmfilterlistbox.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../mailcommon-26.04.3/src/filter/kmfilterlistbox.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmfilterlistbox.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MailCommon15KMFilterListBoxE_t {};
} // unnamed namespace

template <> constexpr inline auto MailCommon::KMFilterListBox::qt_create_metaobjectdata<qt_meta_tag_ZN10MailCommon15KMFilterListBoxE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MailCommon::KMFilterListBox",
        "filterSelected",
        "",
        "MailCommon::MailFilter*",
        "filter",
        "resetWidgets",
        "applyWidgets",
        "abortClosing",
        "filterCreated",
        "filterRemoved",
        "QList<MailCommon::MailFilter*>",
        "filterUpdated",
        "filterOrderAltered",
        "slotUpdateFilterName",
        "slotAccepted",
        "slotApplied",
        "slotSelected",
        "aIdx",
        "slotNew",
        "slotCopy",
        "slotDelete",
        "slotUp",
        "slotDown",
        "slotRename",
        "slotRowsMoved",
        "QModelIndex",
        "slotTop",
        "slotBottom",
        "slotFilterEnabledChanged",
        "QListWidgetItem*",
        "item",
        "slotSelectionChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'filterSelected'
        QtMocHelpers::SignalData<void(MailCommon::MailFilter *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'resetWidgets'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'applyWidgets'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abortClosing'
        QtMocHelpers::SignalData<void() const>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterCreated'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterRemoved'
        QtMocHelpers::SignalData<void(const QList<MailCommon::MailFilter*> &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 4 },
        }}),
        // Signal 'filterUpdated'
        QtMocHelpers::SignalData<void(MailCommon::MailFilter *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'filterOrderAltered'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdateFilterName'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAccepted'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotApplied'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSelected'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'slotNew'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotCopy'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotDelete'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotUp'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotDown'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotRename'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotRowsMoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int, const QModelIndex &, int)>(24, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 25, 2 }, { QMetaType::Int, 2 }, { QMetaType::Int, 2 }, { 0x80000000 | 25, 2 },
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotTop'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotBottom'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotFilterEnabledChanged'
        QtMocHelpers::SlotData<void(QListWidgetItem *)>(28, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'slotSelectionChanged'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KMFilterListBox, qt_meta_tag_ZN10MailCommon15KMFilterListBoxE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MailCommon::KMFilterListBox::staticMetaObject = { {
    QMetaObject::SuperData::link<QGroupBox::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MailCommon15KMFilterListBoxE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MailCommon15KMFilterListBoxE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MailCommon15KMFilterListBoxE_t>.metaTypes,
    nullptr
} };

void MailCommon::KMFilterListBox::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KMFilterListBox *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->filterSelected((*reinterpret_cast<std::add_pointer_t<MailCommon::MailFilter*>>(_a[1]))); break;
        case 1: _t->resetWidgets(); break;
        case 2: _t->applyWidgets(); break;
        case 3: _t->abortClosing(); break;
        case 4: _t->filterCreated(); break;
        case 5: _t->filterRemoved((*reinterpret_cast<std::add_pointer_t<QList<MailCommon::MailFilter*>>>(_a[1]))); break;
        case 6: _t->filterUpdated((*reinterpret_cast<std::add_pointer_t<MailCommon::MailFilter*>>(_a[1]))); break;
        case 7: _t->filterOrderAltered(); break;
        case 8: _t->slotUpdateFilterName(); break;
        case 9: _t->slotAccepted(); break;
        case 10: _t->slotApplied(); break;
        case 11: _t->slotSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->slotNew(); break;
        case 13: _t->slotCopy(); break;
        case 14: _t->slotDelete(); break;
        case 15: _t->slotUp(); break;
        case 16: _t->slotDown(); break;
        case 17: _t->slotRename(); break;
        case 18: _t->slotRowsMoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 19: _t->slotTop(); break;
        case 20: _t->slotBottom(); break;
        case 21: _t->slotFilterEnabledChanged((*reinterpret_cast<std::add_pointer_t<QListWidgetItem*>>(_a[1]))); break;
        case 22: _t->slotSelectionChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KMFilterListBox::*)(MailCommon::MailFilter * )>(_a, &KMFilterListBox::filterSelected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMFilterListBox::*)()>(_a, &KMFilterListBox::resetWidgets, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMFilterListBox::*)()>(_a, &KMFilterListBox::applyWidgets, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMFilterListBox::*)() const>(_a, &KMFilterListBox::abortClosing, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMFilterListBox::*)()>(_a, &KMFilterListBox::filterCreated, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMFilterListBox::*)(const QList<MailCommon::MailFilter*> & )>(_a, &KMFilterListBox::filterRemoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMFilterListBox::*)(MailCommon::MailFilter * )>(_a, &KMFilterListBox::filterUpdated, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KMFilterListBox::*)()>(_a, &KMFilterListBox::filterOrderAltered, 7))
            return;
    }
}

const QMetaObject *MailCommon::KMFilterListBox::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MailCommon::KMFilterListBox::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MailCommon15KMFilterListBoxE_t>.strings))
        return static_cast<void*>(this);
    return QGroupBox::qt_metacast(_clname);
}

int MailCommon::KMFilterListBox::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGroupBox::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void MailCommon::KMFilterListBox::filterSelected(MailCommon::MailFilter * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void MailCommon::KMFilterListBox::resetWidgets()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MailCommon::KMFilterListBox::applyWidgets()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MailCommon::KMFilterListBox::abortClosing()const
{
    QMetaObject::activate(const_cast< MailCommon::KMFilterListBox *>(this), &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MailCommon::KMFilterListBox::filterCreated()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MailCommon::KMFilterListBox::filterRemoved(const QList<MailCommon::MailFilter*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void MailCommon::KMFilterListBox::filterUpdated(MailCommon::MailFilter * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void MailCommon::KMFilterListBox::filterOrderAltered()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
