/****************************************************************************
** Meta object code from reading C++ file 'pop3settings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "pop3settings.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pop3settings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN34OrgKdeAkonadiPOP3SettingsInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdeAkonadiPOP3SettingsInterface::qt_create_metaobjectdata<qt_meta_tag_ZN34OrgKdeAkonadiPOP3SettingsInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdeAkonadiPOP3SettingsInterface",
        "authenticationMethod",
        "QDBusPendingReply<int>",
        "",
        "downloadLater",
        "QDBusPendingReply<QStringList>",
        "filterCheckSize",
        "QDBusPendingReply<uint>",
        "filterOnServer",
        "QDBusPendingReply<bool>",
        "host",
        "QDBusPendingReply<QString>",
        "intervalCheckEnabled",
        "intervalCheckInterval",
        "leaveOnServer",
        "leaveOnServerCount",
        "leaveOnServerDays",
        "leaveOnServerSize",
        "login",
        "pipelining",
        "port",
        "precommand",
        "save",
        "QDBusPendingReply<>",
        "seenUidList",
        "seenUidTimeList",
        "QDBusPendingReply<QList<int>>",
        "setAuthenticationMethod",
        "in0",
        "setDownloadLater",
        "setFilterCheckSize",
        "setFilterOnServer",
        "setHost",
        "setIntervalCheckEnabled",
        "setIntervalCheckInterval",
        "setLeaveOnServer",
        "setLeaveOnServerCount",
        "setLeaveOnServerDays",
        "setLeaveOnServerSize",
        "setLogin",
        "setPipelining",
        "setPort",
        "setPrecommand",
        "setSeenUidList",
        "setSeenUidTimeList",
        "QList<int>",
        "setStorePassword",
        "setTargetCollection",
        "setUnitTestPassword",
        "setUseSSL",
        "setUseTLS",
        "storePassword",
        "targetCollection",
        "QDBusPendingReply<qlonglong>",
        "unitTestPassword",
        "useSSL",
        "useTLS"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'authenticationMethod'
        QtMocHelpers::SlotData<QDBusPendingReply<int>()>(1, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'downloadLater'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(4, 3, QMC::AccessPublic, 0x80000000 | 5),
        // Slot 'filterCheckSize'
        QtMocHelpers::SlotData<QDBusPendingReply<uint>()>(6, 3, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'filterOnServer'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(8, 3, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'host'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(10, 3, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'intervalCheckEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(12, 3, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'intervalCheckInterval'
        QtMocHelpers::SlotData<QDBusPendingReply<int>()>(13, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'leaveOnServer'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(14, 3, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'leaveOnServerCount'
        QtMocHelpers::SlotData<QDBusPendingReply<int>()>(15, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'leaveOnServerDays'
        QtMocHelpers::SlotData<QDBusPendingReply<int>()>(16, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'leaveOnServerSize'
        QtMocHelpers::SlotData<QDBusPendingReply<int>()>(17, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'login'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(18, 3, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'pipelining'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(19, 3, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'port'
        QtMocHelpers::SlotData<QDBusPendingReply<uint>()>(20, 3, QMC::AccessPublic, 0x80000000 | 7),
        // Slot 'precommand'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(21, 3, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'save'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(22, 3, QMC::AccessPublic, 0x80000000 | 23),
        // Slot 'seenUidList'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(24, 3, QMC::AccessPublic, 0x80000000 | 5),
        // Slot 'seenUidTimeList'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<int> >()>(25, 3, QMC::AccessPublic, 0x80000000 | 26),
        // Slot 'setAuthenticationMethod'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(27, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::Int, 28 },
        }}),
        // Slot 'setDownloadLater'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &)>(29, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QStringList, 28 },
        }}),
        // Slot 'setFilterCheckSize'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(30, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::UInt, 28 },
        }}),
        // Slot 'setFilterOnServer'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(31, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'setHost'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(32, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'setIntervalCheckEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(33, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'setIntervalCheckInterval'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(34, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::Int, 28 },
        }}),
        // Slot 'setLeaveOnServer'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(35, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'setLeaveOnServerCount'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(36, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::Int, 28 },
        }}),
        // Slot 'setLeaveOnServerDays'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(37, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::Int, 28 },
        }}),
        // Slot 'setLeaveOnServerSize'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(38, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::Int, 28 },
        }}),
        // Slot 'setLogin'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(39, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'setPipelining'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(40, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'setPort'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(41, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::UInt, 28 },
        }}),
        // Slot 'setPrecommand'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(42, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'setSeenUidList'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &)>(43, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QStringList, 28 },
        }}),
        // Slot 'setSeenUidTimeList'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QList<int> &)>(44, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { 0x80000000 | 45, 28 },
        }}),
        // Slot 'setStorePassword'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(46, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'setTargetCollection'
        QtMocHelpers::SlotData<QDBusPendingReply<>(qlonglong)>(47, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::LongLong, 28 },
        }}),
        // Slot 'setUnitTestPassword'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(48, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::QString, 28 },
        }}),
        // Slot 'setUseSSL'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(49, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'setUseTLS'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(50, 3, QMC::AccessPublic, 0x80000000 | 23, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'storePassword'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(51, 3, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'targetCollection'
        QtMocHelpers::SlotData<QDBusPendingReply<qlonglong>()>(52, 3, QMC::AccessPublic, 0x80000000 | 53),
        // Slot 'unitTestPassword'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(54, 3, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'useSSL'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(55, 3, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'useTLS'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(56, 3, QMC::AccessPublic, 0x80000000 | 9),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdeAkonadiPOP3SettingsInterface, qt_meta_tag_ZN34OrgKdeAkonadiPOP3SettingsInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdeAkonadiPOP3SettingsInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34OrgKdeAkonadiPOP3SettingsInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34OrgKdeAkonadiPOP3SettingsInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN34OrgKdeAkonadiPOP3SettingsInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgKdeAkonadiPOP3SettingsInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdeAkonadiPOP3SettingsInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<int> _r = _t->authenticationMethod();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<QStringList> _r = _t->downloadLater();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<uint> _r = _t->filterCheckSize();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<uint>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<bool> _r = _t->filterOnServer();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<QString> _r = _t->host();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<bool> _r = _t->intervalCheckEnabled();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<int> _r = _t->intervalCheckInterval();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<bool> _r = _t->leaveOnServer();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<int> _r = _t->leaveOnServerCount();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<int> _r = _t->leaveOnServerDays();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<int> _r = _t->leaveOnServerSize();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<QString> _r = _t->login();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<bool> _r = _t->pipelining();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<uint> _r = _t->port();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<uint>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<QString> _r = _t->precommand();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<> _r = _t->save();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<QStringList> _r = _t->seenUidList();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<QList<int>> _r = _t->seenUidTimeList();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<int>>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<> _r = _t->setAuthenticationMethod((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->setDownloadLater((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<> _r = _t->setFilterCheckSize((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<> _r = _t->setFilterOnServer((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<> _r = _t->setHost((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<> _r = _t->setIntervalCheckEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->setIntervalCheckInterval((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<> _r = _t->setLeaveOnServer((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusPendingReply<> _r = _t->setLeaveOnServerCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 27: { QDBusPendingReply<> _r = _t->setLeaveOnServerDays((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 28: { QDBusPendingReply<> _r = _t->setLeaveOnServerSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 29: { QDBusPendingReply<> _r = _t->setLogin((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 30: { QDBusPendingReply<> _r = _t->setPipelining((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 31: { QDBusPendingReply<> _r = _t->setPort((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 32: { QDBusPendingReply<> _r = _t->setPrecommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 33: { QDBusPendingReply<> _r = _t->setSeenUidList((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 34: { QDBusPendingReply<> _r = _t->setSeenUidTimeList((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 35: { QDBusPendingReply<> _r = _t->setStorePassword((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 36: { QDBusPendingReply<> _r = _t->setTargetCollection((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 37: { QDBusPendingReply<> _r = _t->setUnitTestPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 38: { QDBusPendingReply<> _r = _t->setUseSSL((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 39: { QDBusPendingReply<> _r = _t->setUseTLS((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 40: { QDBusPendingReply<bool> _r = _t->storePassword();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 41: { QDBusPendingReply<qlonglong> _r = _t->targetCollection();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<qlonglong>*>(_a[0]) = std::move(_r); }  break;
        case 42: { QDBusPendingReply<QString> _r = _t->unitTestPassword();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 43: { QDBusPendingReply<bool> _r = _t->useSSL();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 44: { QDBusPendingReply<bool> _r = _t->useTLS();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
}

const QMetaObject *OrgKdeAkonadiPOP3SettingsInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdeAkonadiPOP3SettingsInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34OrgKdeAkonadiPOP3SettingsInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdeAkonadiPOP3SettingsInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    return _id;
}
QT_WARNING_POP
