/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.Korganizer.Calendar.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef CALENDARINTERFACE_H
#define CALENDARINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.Korganizer.Calendar
 */
class OrgKdeKorganizerCalendarInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.Korganizer.Calendar"; }

public:
    OrgKdeKorganizerCalendarInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKorganizerCalendarInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> goDate(const QString &date)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(date);
        return asyncCallWithArgumentList(QStringLiteral("goDate"), argumentList);
    }

    inline QDBusPendingReply<> goDate(const QDate &date)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(date);
        return asyncCallWithArgumentList(QStringLiteral("goDate"), argumentList);
    }

    inline QDBusPendingReply<> openEventEditor(const QString &summary, const QString &description, const QStringList &attachmentUris, const QStringList &attendees, const QStringList &attachmentMimetypes, bool attachmentIsInline)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(summary) << QVariant::fromValue(description) << QVariant::fromValue(attachmentUris) << QVariant::fromValue(attendees) << QVariant::fromValue(attachmentMimetypes) << QVariant::fromValue(attachmentIsInline);
        return asyncCallWithArgumentList(QStringLiteral("openEventEditor"), argumentList);
    }

    inline QDBusPendingReply<> openEventEditor(const QString &summary, const QString &description, const QStringList &attachments, const QStringList &attendees)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(summary) << QVariant::fromValue(description) << QVariant::fromValue(attachments) << QVariant::fromValue(attendees);
        return asyncCallWithArgumentList(QStringLiteral("openEventEditor"), argumentList);
    }

    inline QDBusPendingReply<> openEventEditor(const QString &summary, const QString &description, const QString &uri, const QString &file, const QStringList &attendees, const QString &attachmentMimetype)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(summary) << QVariant::fromValue(description) << QVariant::fromValue(uri) << QVariant::fromValue(file) << QVariant::fromValue(attendees) << QVariant::fromValue(attachmentMimetype);
        return asyncCallWithArgumentList(QStringLiteral("openEventEditor"), argumentList);
    }

    inline QDBusPendingReply<> openEventEditor(const QString &summary, const QString &description, const QStringList &attachments)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(summary) << QVariant::fromValue(description) << QVariant::fromValue(attachments);
        return asyncCallWithArgumentList(QStringLiteral("openEventEditor"), argumentList);
    }

    inline QDBusPendingReply<> openEventEditor(const QString &text)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(text);
        return asyncCallWithArgumentList(QStringLiteral("openEventEditor"), argumentList);
    }

    inline QDBusPendingReply<> openJournalEditor(const QString &text)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(text);
        return asyncCallWithArgumentList(QStringLiteral("openJournalEditor"), argumentList);
    }

    inline QDBusPendingReply<> openJournalEditor(const QString &text, const QDate &date)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(text) << QVariant::fromValue(date);
        return asyncCallWithArgumentList(QStringLiteral("openJournalEditor"), argumentList);
    }

    inline QDBusPendingReply<> openJournalEditor(const QDate &date)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(date);
        return asyncCallWithArgumentList(QStringLiteral("openJournalEditor"), argumentList);
    }

    inline QDBusPendingReply<> openTodoEditor(const QString &summary, const QString &description, const QStringList &attachmentUris, const QStringList &attendees, const QStringList &attachmentMimetypes, bool attachmentIsInline)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(summary) << QVariant::fromValue(description) << QVariant::fromValue(attachmentUris) << QVariant::fromValue(attendees) << QVariant::fromValue(attachmentMimetypes) << QVariant::fromValue(attachmentIsInline);
        return asyncCallWithArgumentList(QStringLiteral("openTodoEditor"), argumentList);
    }

    inline QDBusPendingReply<> openTodoEditor(const QString &summary, const QString &description, const QString &uri, const QString &file, const QStringList &attendees, const QString &attachmentMimetype)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(summary) << QVariant::fromValue(description) << QVariant::fromValue(uri) << QVariant::fromValue(file) << QVariant::fromValue(attendees) << QVariant::fromValue(attachmentMimetype);
        return asyncCallWithArgumentList(QStringLiteral("openTodoEditor"), argumentList);
    }

    inline QDBusPendingReply<> openTodoEditor(const QString &summary, const QString &description, const QStringList &attachments, const QStringList &attendees)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(summary) << QVariant::fromValue(description) << QVariant::fromValue(attachments) << QVariant::fromValue(attendees);
        return asyncCallWithArgumentList(QStringLiteral("openTodoEditor"), argumentList);
    }

    inline QDBusPendingReply<> openTodoEditor(const QString &summary, const QString &description, const QStringList &attachments)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(summary) << QVariant::fromValue(description) << QVariant::fromValue(attachments);
        return asyncCallWithArgumentList(QStringLiteral("openTodoEditor"), argumentList);
    }

    inline QDBusPendingReply<> openTodoEditor(const QString &text)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(text);
        return asyncCallWithArgumentList(QStringLiteral("openTodoEditor"), argumentList);
    }

    inline QDBusPendingReply<> showDate(const QDate &date)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(date);
        return asyncCallWithArgumentList(QStringLiteral("showDate"), argumentList);
    }

    inline QDBusPendingReply<> showEventView()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("showEventView"), argumentList);
    }

    inline QDBusPendingReply<> showJournalView()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("showJournalView"), argumentList);
    }

    inline QDBusPendingReply<> showTodoView()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("showTodoView"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace kde {
    namespace Korganizer {
      using Calendar = ::OrgKdeKorganizerCalendarInterface;
    }
  }
}

#endif
