/****************************************************************************
** Meta object code from reading C++ file 'foldertreeview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../mailcommon-26.04.3/src/folder/foldertreeview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'foldertreeview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MailCommon14FolderTreeViewE_t {};
} // unnamed namespace

template <> constexpr inline auto MailCommon::FolderTreeView::qt_create_metaobjectdata<qt_meta_tag_ZN10MailCommon14FolderTreeViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MailCommon::FolderTreeView",
        "changeTooltipsPolicy",
        "",
        "MailCommon::FolderTreeWidget::ToolTipDisplayPolicy",
        "manualSortingChanged",
        "actif",
        "newTabRequested",
        "slotFocusNextFolder",
        "slotFocusPrevFolder",
        "slotSelectFocusFolder",
        "slotFocusFirstFolder",
        "slotFocusLastFolder",
        "slotHeaderContextMenuRequested",
        "QPoint",
        "slotHeaderContextMenuChangeIconSize",
        "slotHeaderContextMenuChangeHeader",
        "slotHeaderContextMenuChangeToolTipDisplayPolicy",
        "slotHeaderContextMenuChangeSortingPolicy"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changeTooltipsPolicy'
        QtMocHelpers::SignalData<void(MailCommon::FolderTreeWidget::ToolTipDisplayPolicy)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'manualSortingChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'newTabRequested'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotFocusNextFolder'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFocusPrevFolder'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSelectFocusFolder'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFocusFirstFolder'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFocusLastFolder'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotHeaderContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(12, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'slotHeaderContextMenuChangeIconSize'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotHeaderContextMenuChangeHeader'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotHeaderContextMenuChangeToolTipDisplayPolicy'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotHeaderContextMenuChangeSortingPolicy'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FolderTreeView, qt_meta_tag_ZN10MailCommon14FolderTreeViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MailCommon::FolderTreeView::staticMetaObject = { {
    QMetaObject::SuperData::link<Akonadi::EntityTreeView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MailCommon14FolderTreeViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MailCommon14FolderTreeViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MailCommon14FolderTreeViewE_t>.metaTypes,
    nullptr
} };

void MailCommon::FolderTreeView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FolderTreeView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changeTooltipsPolicy((*reinterpret_cast<std::add_pointer_t<MailCommon::FolderTreeWidget::ToolTipDisplayPolicy>>(_a[1]))); break;
        case 1: _t->manualSortingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->newTabRequested((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->slotFocusNextFolder(); break;
        case 4: _t->slotFocusPrevFolder(); break;
        case 5: _t->slotSelectFocusFolder(); break;
        case 6: _t->slotFocusFirstFolder(); break;
        case 7: _t->slotFocusLastFolder(); break;
        case 8: _t->slotHeaderContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 9: _t->slotHeaderContextMenuChangeIconSize((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->slotHeaderContextMenuChangeHeader((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->slotHeaderContextMenuChangeToolTipDisplayPolicy((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->slotHeaderContextMenuChangeSortingPolicy((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FolderTreeView::*)(MailCommon::FolderTreeWidget::ToolTipDisplayPolicy )>(_a, &FolderTreeView::changeTooltipsPolicy, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderTreeView::*)(bool )>(_a, &FolderTreeView::manualSortingChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FolderTreeView::*)(bool )>(_a, &FolderTreeView::newTabRequested, 2))
            return;
    }
}

const QMetaObject *MailCommon::FolderTreeView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MailCommon::FolderTreeView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MailCommon14FolderTreeViewE_t>.strings))
        return static_cast<void*>(this);
    return Akonadi::EntityTreeView::qt_metacast(_clname);
}

int MailCommon::FolderTreeView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Akonadi::EntityTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void MailCommon::FolderTreeView::changeTooltipsPolicy(MailCommon::FolderTreeWidget::ToolTipDisplayPolicy _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void MailCommon::FolderTreeView::manualSortingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void MailCommon::FolderTreeView::newTabRequested(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
