/****************************************************************************
** Meta object code from reading C++ file 'mailfilteragentinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "mailfilteragentinterface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mailfilteragentinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN45OrgFreedesktopAkonadiMailFilterAgentInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgFreedesktopAkonadiMailFilterAgentInterface::qt_create_metaobjectdata<qt_meta_tag_ZN45OrgFreedesktopAkonadiMailFilterAgentInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgFreedesktopAkonadiMailFilterAgentInterface",
        "filtersChanged",
        "",
        "applySpecificFilters",
        "QDBusPendingReply<>",
        "QList<qint64>",
        "items",
        "FilterRequires",
        "listFilters",
        "applySpecificFiltersOnCollections",
        "collections",
        "filterSet",
        "createUniqueName",
        "QDBusPendingReply<QString>",
        "nameTemplate",
        "expunge",
        "collectionId",
        "filter",
        "item",
        "filterIdentifier",
        "resourceId",
        "filterCollections",
        "filterItem",
        "filterItems",
        "printCollectionMonitored",
        "reload",
        "showFilterLogDialog",
        "windowId"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'filtersChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'applySpecificFilters'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QList<qint64> &, int, const QStringList &)>(3, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 5, 6 }, { QMetaType::Int, 7 }, { QMetaType::QStringList, 8 },
        }}),
        // Slot 'applySpecificFiltersOnCollections'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QList<qint64> &, const QStringList &, int)>(9, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 5, 10 }, { QMetaType::QStringList, 8 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'createUniqueName'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(12, 2, QMC::AccessPublic, 0x80000000 | 13, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'expunge'
        QtMocHelpers::SlotData<QDBusPendingReply<>(qlonglong)>(15, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::LongLong, 16 },
        }}),
        // Slot 'filter'
        QtMocHelpers::SlotData<QDBusPendingReply<>(qlonglong, const QString &, const QString &)>(17, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::LongLong, 18 }, { QMetaType::QString, 19 }, { QMetaType::QString, 20 },
        }}),
        // Slot 'filterCollections'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QList<qint64> &, int)>(21, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 5, 10 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'filterItem'
        QtMocHelpers::SlotData<QDBusPendingReply<>(qlonglong, int, const QString &)>(22, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::LongLong, 18 }, { QMetaType::Int, 11 }, { QMetaType::QString, 20 },
        }}),
        // Slot 'filterItems'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QList<qint64> &, int)>(23, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 5, 6 }, { QMetaType::Int, 11 },
        }}),
        // Slot 'printCollectionMonitored'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(24, 2, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'reload'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(25, 2, QMC::AccessPublic, 0x80000000 | 4),
        // Slot 'showFilterLogDialog'
        QtMocHelpers::SlotData<QDBusPendingReply<>(qlonglong)>(26, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::LongLong, 27 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgFreedesktopAkonadiMailFilterAgentInterface, qt_meta_tag_ZN45OrgFreedesktopAkonadiMailFilterAgentInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgFreedesktopAkonadiMailFilterAgentInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN45OrgFreedesktopAkonadiMailFilterAgentInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN45OrgFreedesktopAkonadiMailFilterAgentInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN45OrgFreedesktopAkonadiMailFilterAgentInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgFreedesktopAkonadiMailFilterAgentInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgFreedesktopAkonadiMailFilterAgentInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->filtersChanged(); break;
        case 1: { QDBusPendingReply<> _r = _t->applySpecificFilters((*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->applySpecificFiltersOnCollections((*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<QString> _r = _t->createUniqueName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->expunge((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<> _r = _t->filter((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<> _r = _t->filterCollections((*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->filterItem((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->filterItems((*reinterpret_cast<std::add_pointer_t<QList<qint64>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 9: { QDBusPendingReply<QString> _r = _t->printCollectionMonitored();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 10: { QDBusPendingReply<> _r = _t->reload();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->showFilterLogDialog((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qint64> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgFreedesktopAkonadiMailFilterAgentInterface::*)()>(_a, &OrgFreedesktopAkonadiMailFilterAgentInterface::filtersChanged, 0))
            return;
    }
}

const QMetaObject *OrgFreedesktopAkonadiMailFilterAgentInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgFreedesktopAkonadiMailFilterAgentInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN45OrgFreedesktopAkonadiMailFilterAgentInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgFreedesktopAkonadiMailFilterAgentInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void OrgFreedesktopAkonadiMailFilterAgentInterface::filtersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
