/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Akonadi.MailFilterAgent.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef MAILFILTERAGENTINTERFACE_H
#define MAILFILTERAGENTINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "dbusoperators.h"

/*
 * Proxy class for interface org.freedesktop.Akonadi.MailFilterAgent
 */
class OrgFreedesktopAkonadiMailFilterAgentInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.Akonadi.MailFilterAgent"; }

public:
    OrgFreedesktopAkonadiMailFilterAgentInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopAkonadiMailFilterAgentInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> applySpecificFilters(const QList<qint64> & items, int FilterRequires, const QStringList &listFilters)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(items) << QVariant::fromValue(FilterRequires) << QVariant::fromValue(listFilters);
        return asyncCallWithArgumentList(QStringLiteral("applySpecificFilters"), argumentList);
    }

    inline QDBusPendingReply<> applySpecificFiltersOnCollections(const QList<qint64> & collections, const QStringList &listFilters, int filterSet)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(collections) << QVariant::fromValue(listFilters) << QVariant::fromValue(filterSet);
        return asyncCallWithArgumentList(QStringLiteral("applySpecificFiltersOnCollections"), argumentList);
    }

    inline QDBusPendingReply<QString> createUniqueName(const QString &nameTemplate)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(nameTemplate);
        return asyncCallWithArgumentList(QStringLiteral("createUniqueName"), argumentList);
    }

    inline QDBusPendingReply<> expunge(qlonglong collectionId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(collectionId);
        return asyncCallWithArgumentList(QStringLiteral("expunge"), argumentList);
    }

    inline QDBusPendingReply<> filter(qlonglong item, const QString &filterIdentifier, const QString &resourceId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(item) << QVariant::fromValue(filterIdentifier) << QVariant::fromValue(resourceId);
        return asyncCallWithArgumentList(QStringLiteral("filter"), argumentList);
    }

    inline QDBusPendingReply<> filterCollections(const QList<qint64> & collections, int filterSet)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(collections) << QVariant::fromValue(filterSet);
        return asyncCallWithArgumentList(QStringLiteral("filterCollections"), argumentList);
    }

    inline QDBusPendingReply<> filterItem(qlonglong item, int filterSet, const QString &resourceId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(item) << QVariant::fromValue(filterSet) << QVariant::fromValue(resourceId);
        return asyncCallWithArgumentList(QStringLiteral("filterItem"), argumentList);
    }

    inline QDBusPendingReply<> filterItems(const QList<qint64> & items, int filterSet)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(items) << QVariant::fromValue(filterSet);
        return asyncCallWithArgumentList(QStringLiteral("filterItems"), argumentList);
    }

    inline QDBusPendingReply<QString> printCollectionMonitored()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("printCollectionMonitored"), argumentList);
    }

    inline QDBusPendingReply<> reload()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("reload"), argumentList);
    }

    inline QDBusPendingReply<> showFilterLogDialog(qlonglong windowId)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(windowId);
        return asyncCallWithArgumentList(QStringLiteral("showFilterLogDialog"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void filtersChanged();
};

namespace org {
  namespace freedesktop {
    namespace Akonadi {
      using MailFilterAgent = ::OrgFreedesktopAkonadiMailFilterAgentInterface;
    }
  }
}

#endif
