// This file is generated by kconfig_compiler_kf6 from mailcommon.kcfg.
// All changes you do to this file will be lost.

#include "mailcommonsettings_base.h"

#include <klocalizedstring.h>

using namespace MailCommon;

MailCommonSettings::MailCommonSettings( )
  : KConfigSkeleton()
{
  setCurrentGroup( QStringLiteral( "FavoriteCollectionWidget" ) );

  mIconSizeItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "IconSize" ), mIconSize, 22 );
  mIconSizeItem->setLabel( i18nd("libmailcommon6", "IconSize") );
  addItem( mIconSizeItem, QStringLiteral( "IconSize" ) );

  setCurrentGroup( QStringLiteral( "FavoriteCollectionView" ) );

  mFavoriteCollectionViewHeightItem = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "FavoriteCollectionViewHeight" ), mFavoriteCollectionViewHeight, 100 );
  mFavoriteCollectionViewHeightItem->setLabel( i18nd("libmailcommon6", "FavoriteCollectionViewHeight") );
  addItem( mFavoriteCollectionViewHeightItem, QStringLiteral( "FavoriteCollectionViewHeight" ) );
  QList<KConfigSkeleton::ItemEnum::Choice> valuesFavoriteCollectionViewMode;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("HiddenMode");
    choice.label = i18nd("libmailcommon6", "Do not show the favorite folders view.");
    valuesFavoriteCollectionViewMode.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("IconMode");
    choice.label = i18nd("libmailcommon6", "Show favorite folders in icon mode.");
    valuesFavoriteCollectionViewMode.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("ListMode");
    choice.label = i18nd("libmailcommon6", "Show favorite folders in list mode.");
    valuesFavoriteCollectionViewMode.append( choice );
  }
  mFavoriteCollectionViewModeItem = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "FavoriteCollectionViewMode" ), mFavoriteCollectionViewMode, valuesFavoriteCollectionViewMode, EnumFavoriteCollectionViewMode::IconMode );
  mFavoriteCollectionViewModeItem->setLabel( i18nd("libmailcommon6", "Display Mode of the Favorite Collections View") );
  addItem( mFavoriteCollectionViewModeItem, QStringLiteral( "FavoriteCollectionViewMode" ) );

  setCurrentGroup( QStringLiteral( "AccountOrder" ) );

  mOrderItem = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "order" ), mOrder );
  mOrderItem->setLabel( i18nd("libmailcommon6", "order") );
  addItem( mOrderItem, QStringLiteral( "order" ) );
  mEnableAccountOrderItem = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "EnableAccountOrder" ), mEnableAccountOrder, true );
  mEnableAccountOrderItem->setLabel( i18nd("libmailcommon6", "EnableAccountOrder") );
  addItem( mEnableAccountOrderItem, QStringLiteral( "EnableAccountOrder" ) );
}

MailCommonSettings::~MailCommonSettings()
{
}

